pub struct DelayedPaymentOutputDescriptor {
pub outpoint: OutPoint,
pub per_commitment_point: PublicKey,
pub to_self_delay: u16,
pub output: TxOut,
pub revocation_pubkey: PublicKey,
pub channel_keys_id: [u8; 32],
pub channel_value_satoshis: u64,
}Expand description
Information about a spendable output to a P2WSH script.
See SpendableOutputDescriptor::DelayedPaymentOutput for more details on how to spend this.
Fields
outpoint: OutPointThe outpoint which is spendable.
per_commitment_point: PublicKeyPer commitment point to derive the delayed payment key by key holder.
to_self_delay: u16The nSequence value which must be set in the spending input to satisfy the OP_CSV in
the witness_script.
output: TxOutThe output which is referenced by the given outpoint.
revocation_pubkey: PublicKeyThe revocation point specific to the commitment transaction which was broadcast. Used to derive the witnessScript for this output.
channel_keys_id: [u8; 32]Arbitrary identification information returned by a call to BaseSign::channel_keys_id.
This may be useful in re-deriving keys used in the channel to spend the output.
channel_value_satoshis: u64The value of the channel which this output originated from, possibly indirectly.
Implementations
Sourceimpl DelayedPaymentOutputDescriptor
impl DelayedPaymentOutputDescriptor
Sourcepub const MAX_WITNESS_LENGTH: usize = 153usize
pub const MAX_WITNESS_LENGTH: usize = 153usize
The maximum length a well-formed witness spending one of these should have.