pub struct StaticPaymentOutputDescriptor {
pub outpoint: OutPoint,
pub output: TxOut,
pub channel_keys_id: [u8; 32],
pub channel_value_satoshis: u64,
}Expand description
Information about a spendable output to our “payment key”.
See SpendableOutputDescriptor::StaticPaymentOutput for more details on how to spend this.
Fields
outpoint: OutPointThe outpoint which is spendable.
output: TxOutThe output which is referenced by the given outpoint.
channel_keys_id: [u8; 32]Arbitrary identification information returned by a call to BaseSign::channel_keys_id.
This may be useful in re-deriving keys used in the channel to spend the output.
channel_value_satoshis: u64The value of the channel which this transactions spends.
Implementations
Sourceimpl StaticPaymentOutputDescriptor
impl StaticPaymentOutputDescriptor
Sourcepub const MAX_WITNESS_LENGTH: usize = 108usize
pub const MAX_WITNESS_LENGTH: usize = 108usize
The maximum length a well-formed witness spending one of these should have.