pub struct HTLCOutputInCommitment {
pub offered: bool,
pub amount_msat: u64,
pub cltv_expiry: u32,
pub payment_hash: PaymentHash,
pub transaction_output_index: Option<u32>,
}Expand description
Information about an HTLC as it appears in a commitment transaction
Fields
offered: boolWhether the HTLC was “offered” (ie outbound in relation to this commitment transaction). Note that this is not the same as whether it is ountbound from us. To determine that you need to compare this value to whether the commitment transaction in question is that of the counterparty or our own.
amount_msat: u64The value, in msat, of the HTLC. The value as it appears in the commitment transaction is this divided by 1000.
cltv_expiry: u32The CLTV lock-time at which this HTLC expires.
payment_hash: PaymentHashThe hash of the preimage which unlocks this HTLC.
transaction_output_index: Option<u32>The position within the commitment transactions’ outputs. This may be None if the value is below the dust limit (in which case no output appears in the commitment transaction and the value is spent to additional transaction fees).