pub enum DecodeError {
UnknownVersion,
UnknownRequiredFeature,
InvalidValue,
ShortRead,
BadLengthDescriptor,
Io(ErrorKind),
UnsupportedCompression,
}Expand description
An error in decoding a message or struct.
Variants
UnknownVersion
A version byte specified something we don’t know how to handle. Includes unknown realm byte in an OnionHopData packet
UnknownRequiredFeature
Unknown feature mandating we fail to parse message (eg TLV with an even, unknown type)
InvalidValue
Value was invalid, eg a byte which was supposed to be a bool was something other than a 0 or 1, a public key/private key/signature was invalid, text wasn’t UTF-8, TLV was syntactically incorrect, etc
ShortRead
Buffer too short
BadLengthDescriptor
A length descriptor in the packet didn’t describe the later data correctly
Io(ErrorKind)
Error from std::io
UnsupportedCompression
The message included zlib-compressed values, which we don’t support.