Enum SendError

pub enum SendError {
    Secp256k1(Error),
    TooBigPacket,
    TooFewBlindedHops,
    InvalidFirstHop,
    InvalidMessage,
    BufferFull,
    GetNodeIdFailed,
    BlindedPathAdvanceFailed,
}
Errors that may occur when sending an onion message.

Variants



Secp256k1(Error)

Errored computing onion message packet keys.



TooBigPacket

Because implementations such as Eclair will drop onion messages where the message packet exceeds 32834 bytes, we refuse to send messages where the packet exceeds this size.



TooFewBlindedHops

The provided Destination was an invalid BlindedPath, due to having fewer than two blinded hops.



InvalidFirstHop

Our next-hop peer was offline or does not support onion message forwarding.



InvalidMessage

Onion message contents must have a TLV type >= 64.



BufferFull

Our next-hop peer’s buffer was full or our total outbound buffer was full.



GetNodeIdFailed

Failed to retrieve our node id from the provided KeysInterface.



BlindedPathAdvanceFailed

We attempted to send to a blinded path where we are the introduction node, and failed to advance the blinded path to make the second hop the new introduction node. Either KeysInterface::ecdh failed, we failed to tweak the current blinding point to get the new blinding point, or we were attempting to send to ourselves.