Enum ConfirmationTarget

pub enum ConfirmationTarget {
    Background,
    Normal,
    HighPriority,
}
An enum that represents the speed at which we want a transaction to confirm used for feerate estimation.

Variants



Background

We are happy with this transaction confirming slowly when feerate drops some.



Normal

We’d like this transaction to confirm without major delay, but 12-18 blocks is fine.



HighPriority

We’d like this transaction to confirm in the next few blocks.