pub struct PeerHandleError {
pub no_connection_possible: bool,
}Expand description
Error for PeerManager errors. If you get one of these, you must disconnect the socket and generate no further read_event/write_buffer_space_avail/socket_disconnected calls for the descriptor.
Fields
no_connection_possible: boolUsed to indicate that we probably can’t make any future connections to this peer (e.g. because we required features that our peer was missing, or vice versa).
While LDK’s ChannelManager will not do it automatically, you likely wish to force-close
any channels with this peer or check for new versions of LDK.